@@ -9,7 +9,7 @@ from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.utils.context import Context
 from anyscale.compute_config.models import ComputeConfig
-from anyscale.job.models import JobConfig, JobState
+from anyscale.job.models import JobConfig, JobQueueConfig, JobState
 from anyscale.service.models import RayGCSExternalStorageConfig, ServiceConfig, ServiceState
 
 from anyscale_provider.hooks.anyscale import AnyscaleHook
@@ -26,6 +26,7 @@ class SubmitAnyscaleJob(BaseOperator):
 
     :param conn_id: Required. The connection ID for Anyscale.
     :param entrypoint: Required. Command that will be run to execute the job, e.g., `python main.py`.
+    :param job_queue_config: Optional. Allow users to specify JobQueueConfig (more information: https://docs.anyscale.com/platform/jobs/job-queues/ and https://docs.anyscale.com/reference/job-api/).
     :param name: Optional. Name of the job. Multiple jobs can be submitted with the same name.
     :param image_uri: Optional. URI of an existing image. Exclusive with `containerfile`.
     :param containerfile: Optional. The file path to a containerfile that will be built into an image before running the workload. Exclusive with `image_uri`.
@@ -81,6 +82,7 @@ class SubmitAnyscaleJob(BaseOperator):
         wait_for_completion: bool = True,
         job_timeout_seconds: float = 3600,
         poll_interval: float = 60,
+        job_queue_config: JobQueueConfig | None = None,
         *args: Any,
         **kwargs: Any,
     ) -> None:
@@ -103,6 +105,7 @@ class SubmitAnyscaleJob(BaseOperator):
         self.wait_for_completion = wait_for_completion
         self.job_timeout_seconds = job_timeout_seconds
         self.poll_interval = poll_interval
+        self.job_queue_config = job_queue_config
 
         self.job_id: str | None = None
 
@@ -123,7 +126,7 @@ class SubmitAnyscaleJob(BaseOperator):
         """Return an instance of the AnyscaleHook."""
         return AnyscaleHook(conn_id=self.conn_id)
 
-    def execute(self, context: Context) -> None:
+    def execute(self, context: Context) -> str:
         """
         Execute the job submission to Anyscale.
 
@@ -148,6 +151,7 @@ class SubmitAnyscaleJob(BaseOperator):
             "cloud": self.cloud,
             "project": self.project,
             "max_retries": self.max_retries,
+            "job_queue_config": self.job_queue_config,
         }
 
         self.log.info(f"Using Anyscale version {anyscale.__version__}")
@@ -180,8 +184,9 @@ class SubmitAnyscaleJob(BaseOperator):
                 )
             else:
                 raise Exception(f"Unexpected state `{current_state}` for job_id `{self.job_id}`.")
+        return self.job_id
 
-    def execute_complete(self, context: Context, event: Any) -> None:
+    def execute_complete(self, context: Context, event: Any) -> str:
         """
         Complete the execution of the job based on the trigger event.
 
@@ -192,7 +197,7 @@ class SubmitAnyscaleJob(BaseOperator):
         :param event: The event data from the trigger.
         :return: None
         """
-        current_job_id = event["job_id"]
+        current_job_id: str = event["job_id"]
 
         if event["state"] == JobState.FAILED:
             self.log.info(f"Anyscale job {current_job_id} ended with state: {event['state']}")
@@ -200,6 +205,8 @@ class SubmitAnyscaleJob(BaseOperator):
         else:
             self.log.info(f"Anyscale job {current_job_id} completed with state: {event['state']}")
 
+        return current_job_id
+
 
 class RolloutAnyscaleService(BaseOperator):
     """
